package xyz.twovb.sgm.guis;

/*
 * Created by 2vb - 5/7/2024
 */

/*
 * Created by 2vb - 5/7/2024
 */

import com.github.stefvanschie.inventoryframework.gui.GuiItem;
import com.github.stefvanschie.inventoryframework.gui.type.ChestGui;
import com.github.stefvanschie.inventoryframework.pane.OutlinePane;
import lombok.Getter;
import net.kyori.adventure.text.Component;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import xyz.twovb.sgm.SGM;
import xyz.twovb.sgm.games.GameManager;
import xyz.twovb.sgm.games.Minigame;
import xyz.twovb.toolbox.utils.ChatUtils;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.InputStream;
import java.nio.file.Files;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;

public class ActiveGamesGui {

    @Getter
    private final ChestGui gui;

    private final String game;
    private OutlinePane mapPane;

    public ActiveGamesGui(String game) {
        this.game = game;
        ChestGui loadedGui = null;
        try {
            File guiFile = new File(SGM.getInstance().getDataFolder(), "guis/activegames.xml");
            if (guiFile.exists()) {
                byte[] fileContent = Files.readAllBytes(guiFile.toPath());
                InputStream inputStream = new ByteArrayInputStream(fileContent);
                loadedGui = ChestGui.load(this, inputStream);
                mapPane = new OutlinePane(1, 1, 7, 1); // Define your pane layout
                loadedGui.addPane(mapPane);
                addMaps();
            } else {
                SGM.getInstance().getLogger().log(Level.WARNING, "Could not find activegames.xml file.");
            }
        } catch (Exception e) {
            SGM.getInstance().getLogger().log(Level.SEVERE, "Error loading activegames.xml", e);
        }
        gui = loadedGui;
    }

    public void globalClick(InventoryClickEvent event) {
        event.setCancelled(true);
    }

    public void addMaps() {
        for (Minigame game : GameManager.getActiveGames().values()) {
//            SGM.getInstance().getCLogger().log(game.getName());
//            SGM.getInstance().getCLogger().log(this.game);
            Material itemType;
            switch (game.getState()) {
                case PRESTART:
//                    mapItem.setType(Material.YELLOW_WOOL);
                    itemType = Material.YELLOW_WOOL;
                    break;
                case READY:
//                    mapItem.setType(Material.LIME_WOOL);
                    itemType = Material.LIME_WOOL;
                    break;
                case STARTED:
                case ENDING:
                default:
//                    mapItem.setType(Material.RED_WOOL);
                    itemType = Material.RED_WOOL;
                    break;
            }
            ItemStack joinItem = new ItemStack(itemType);
            ItemMeta meta = joinItem.getItemMeta();
            meta.displayName(ChatUtils.translate(game.getName()));
            List<Component> lore = new ArrayList<Component>();
            lore.add(0, ChatUtils.translate("&r&7" + game.getGameId().toString()));
            if (!game.getPlayers().isEmpty()) {
                lore.add(ChatUtils.translate("&r&7Players:"));
                for (Player player : game.getPlayers()) {
                    lore.add(ChatUtils.translate("&r&a" + player.getName()));
                }
            }
            meta.lore(lore);
            joinItem.setItemMeta(meta);
            mapPane.addItem(new GuiItem(joinItem, event -> {
                Player player = (Player) event.getWhoClicked();
                if (game.getState() == Minigame.GameState.READY) {
                    SGM.getInstance().getGameManager().addPlayerToGame(player, game.getGameId());
                }
                player.closeInventory();
            }));
        }
    }
}
